#!/usr/bin/env python
# -*- coding: utf_8 -*-

import uuid
from datetime import datetime
from pony.orm import PrimaryKey, Required, Optional, Set, LongStr, Json
from app import config
from . import fullStackDB

db = fullStackDB.db

class Framework(db.Entity):
    _table_ = "{}".format(config['TABLE_PREFIX']) + "framework"
    id = PrimaryKey(int, auto=True)
    uuid = Required(uuid.UUID, unique=True, default=uuid.uuid1, index=True)
    name = Required(str) # 名称
    url = Required(str) # 路径
    desc = Required(str) # 描述信息
    type = Required(str)  # 模板类型
    assets = Optional(Json, default={}) # 静态资源文件
    create_at = Required(datetime, default=datetime.now)
    create_by = Required("User", reverse='framework_creator')
    update_at = Required(datetime, default=datetime.now)
    update_by = Required("User", reverse='framework_updater')
    delete_at = Optional(datetime)
    delete_by = Optional("User", reverse='framework_deleter')
    is_delete = Required(bool, default=False)
    sort = Optional(int, size=32, default=0)
    remarks = Optional(str, max_len=255, default="", nullable=True)